'use strict';/* global $ */Object.defineProperty(exports,"__esModule",{value:true});var _extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i];for(var key in source){if(Object.prototype.hasOwnProperty.call(source,key)){target[key]=source[key];}}}return target;};var _createClass=function(){function defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}return function(Constructor,protoProps,staticProps){if(protoProps)defineProperties(Constructor.prototype,protoProps);if(staticProps)defineProperties(Constructor,staticProps);return Constructor;};}();var _propTypes=require('prop-types');var _propTypes2=_interopRequireDefault(_propTypes);var _react=require('react');var _react2=_interopRequireDefault(_react);var _itemFactoryBuilder=require('./item-factory-builder');var _itemFactoryBuilder2=_interopRequireDefault(_itemFactoryBuilder);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj};}function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else{obj[key]=value;}return obj;}function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}function _possibleConstructorReturn(self,call){if(!self){throw new ReferenceError("this hasn't been initialised - super() hasn't been called");}return call&&(typeof call==="object"||typeof call==="function")?call:self;}function _inherits(subClass,superClass){if(typeof superClass!=="function"&&superClass!==null){throw new TypeError("Super expression must either be null or a function, not "+typeof superClass);}subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,enumerable:false,writable:true,configurable:true}});if(superClass)Object.setPrototypeOf?Object.setPrototypeOf(subClass,superClass):subClass.__proto__=superClass;}/**
* This React component is to overrdie by Item setting panel class definition.
* An Item setting panel is the modal shown when the user adds a new item on the dashboard,
* or when he wants to change an existing item parameters.
*
* ## render:
* The only mandatory element to implement in the superclass is the render method (as always for a React component)
* The returned value should be like this example:
* <div className='clearing padded'>
*   Put what you want here :)
*   <Button waves={waves} className={cx('right btn-bottom-sticky', theme.actions.primary)} onClick={this.save.bind(this)}>
*     Save &amp; close
*   </Button>
* </div>
*
* And the save method should call this.next(ClassItem, this.state.params) that will save parameters, close the panel and create the item on the dashboard.
*
* ## state:
* The component state contains precious objects to work with:
* - this.state.params: the item params, an object to store item attributes (settings to manipulate in the panel)
* - this.state.item: warning, this element can be null if the item has never been displayed (in a "new item" case). Set asynchronously from outside.
*
* See examples to start implementing your own superclass.
*
* @see https://github.com/gxapplications/asterism/blob/master/lib/plugins/navigation-tools/go-to-path-button/setting-panel.jsx
* @see https://github.com/gxapplications/asterism/blob/master/lib/plugins/scenarii/action-button/setting-panel.jsx
* @hideconstructor
* @memberof module:Asterism
* @public
* @abstract
*/var ItemSettingPanel=function(_React$Component){_inherits(ItemSettingPanel,_React$Component);/**
   * React properties to use on this component.
   *
   * @property {string} icon - Icon show on the setting panel header.
   * @property {string} title - The setting panel title, shown on the header.
   * @property {string} id - The item ID.
   * @property {object} item - The item object, to use in extrem cases only.
   * @property {object} initialParams - The initial params to use to initialize the item. To use as default params objects.
   * @property {function} save - Used in the next() method (or manually if needed) to save item params to persistance layer.
   * @property {integer} preferredHeight - The height that will be used when the item is shown the first time on the dashboard (see ItemFactoryBuilder class).
   * @property {integer} preferredWidth - The width that will be used when the item is shown the first time on the dashboard (see ItemFactoryBuilder class).
   * @property {object[]} acceptedDimensions - Array of simple object of type { w: X, h: Y }, X and Y between 1 to 3, to describe accepted dimensions for the item (see ItemFactoryBuilder class).
   * @property {function} settingPanelCallback - The method callled by next() method after saving/updating the item and its params, to close the panel and refresh dashboard.
   * @property {object} context - The asterism context given to have links to services or usefull objects.
   * @public
   */function ItemSettingPanel(props){_classCallCheck(this,ItemSettingPanel);var _this=_possibleConstructorReturn(this,(ItemSettingPanel.__proto__||Object.getPrototypeOf(ItemSettingPanel)).call(this,props));_this.state={params:_extends({},props.initialParams),item:null// will be set by a ItemLinker instance
};return _this;}/**
   * A useful method to store a new value in a named parameter.
   *
   * @example <caption>Can use it in React JSX syntax</caption>
   * <ActionsDropdown defaultActionId={action} onChange={this.handleValueChange.bind(this, 'action')}
   *   ref={(c) => { this._action = c }} theme={theme} animationLevel={animationLevel}
   *   services={() => this.props.context.services} />
   *
   * @param {string} field - The attribute name to store the value in this.state.params, as a string
   * @param {object} value - The raw value to insert/update in the params.
   *//**
   * Default properties values.
   *
   * @property {string} icon - Default to no icon.
   * @property {string} title - Default to no title.
   * @property {object} item - The item object, default to null (this is the case for an instance creation, not for a setting update of an existing item).
   * @property {object} initialParams - Default to empty object. Filled by previous item params for a setting update of an existing item.
   * @property {integer} preferredHeight - Default to 1.
   * @property {integer} preferredWidth - Default to 1.
   * @property {object[]} acceptedDimensions - Default to [{ w: 1, h: 1 }].
   * @public
   */_createClass(ItemSettingPanel,[{key:'handleValueChange',value:function handleValueChange(field,value){this.setState({params:_extends({},this.state.params,_defineProperty({},field,value))});}/**
   * A useful method to store a new value in a named parameter.
   * This is a variation of handleValueChange, that will take a HTML DOM event as parameter instead of a raw value,
   * to look into it event.target.value.
   *
   * @example <caption>Can use it in React JSX syntax</caption>
   * <Input s={12} label='Label' ref={(c) => { this._title = c }}
   *   value={title} onChange={this.handleEventChange.bind(this, 'title')}>
   *
   * @param {string} field - The attribute name to store the value in this.state.params, as a string
   * @param {object} event - The HTML DOM event triggered, containing the value to store into the params.
   */},{key:'handleEventChange',value:function handleEventChange(field,event){this.setState({params:_extends({},this.state.params,_defineProperty({},field,event.target.value))});}/**
   * Call this method when the settings are ok and the user wants to validate them, create/update the item and close the panel.
   *
   * @param {class} ItemClass - The Item class, to let asterism know what type of Item it should create. Most of the time this should be a static import of a class, but can also be dynamic!
   * @param {object} params - In most of the cases, this.state.params
   */},{key:'next',value:function next(ItemClass,params){var _this2=this;var _props=this.props,id=_props.id,save=_props.save,preferredHeight=_props.preferredHeight,preferredWidth=_props.preferredWidth,settingPanelCallback=_props.settingPanelCallback,acceptedDimensions=_props.acceptedDimensions,context=_props.context;var item=this.state.item;if(item){// it's an item update, return nothing but update item here
save(params).then(function(){if(item.receiveNewParams){item.receiveNewParams(params);}settingPanelCallback();});}else{// it's a new item creation, return the full structure
save(params).then(function(){var itemLinker=new _itemFactoryBuilder2.default.ItemLinker();var newItem=_react2.default.createElement(ItemClass,{id:id,initialParams:params,context:context,ref:function ref(c){return itemLinker.receiveItem(c);},acceptedDimensions:acceptedDimensions});var newSettingPanel=_react2.default.createElement(_this2.constructor,{ref:function ref(c){return itemLinker.receiveItemSettingPanel(c);},icon:_this2.props.icon,title:_this2.props.title,id:id,initialParams:params,item:newItem,context:context,save:save,acceptedDimensions:acceptedDimensions,settingPanelCallback:settingPanelCallback});return settingPanelCallback({id:id,item:newItem,preferredHeight:preferredHeight,preferredWidth:preferredWidth,settingPanel:newSettingPanel});});}}},{key:'gotToSettings',value:function gotToSettings(tabId){var _this3=this;$('#item-setting-modal').modal('close');setTimeout(function(){_this3.props.context.mainState.set({itemSettingPanel:null});$('#settings-modal').modal('open');try{var id=$('#'+tabId).parent().attr('id');setTimeout(function(){$('#settings-modal ul.tabs').tabs('select_tab',id);},400);}catch(error){console.error(error);}},400);}}]);return ItemSettingPanel;}(_react2.default.Component);ItemSettingPanel.propTypes={icon:_propTypes2.default.string,title:_propTypes2.default.string,id:_propTypes2.default.string.isRequired,item:_propTypes2.default.object,initialParams:_propTypes2.default.object,save:_propTypes2.default.func.isRequired,preferredHeight:_propTypes2.default.number,preferredWidth:_propTypes2.default.number,acceptedDimensions:_propTypes2.default.array.isRequired,settingPanelCallback:_propTypes2.default.func.isRequired,// should be called without args if props.item is not null, else
// should return a full new structure : { id,item,preferredHeight,preferredWidth,settingPanel(optional) }
context:_propTypes2.default.object.isRequired};ItemSettingPanel.defaultProps={icon:'',title:'',item:null,initialParams:{},preferredHeight:1,preferredWidth:1,acceptedDimensions:[{w:1,h:1}]};exports.default=ItemSettingPanel;