'use strict';Object.defineProperty(exports,"__esModule",{value:true});var _extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i];for(var key in source){if(Object.prototype.hasOwnProperty.call(source,key)){target[key]=source[key];}}}return target;};var _createClass=function(){function defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}return function(Constructor,protoProps,staticProps){if(protoProps)defineProperties(Constructor.prototype,protoProps);if(staticProps)defineProperties(Constructor,staticProps);return Constructor;};}();var _propTypes=require('prop-types');var _propTypes2=_interopRequireDefault(_propTypes);var _react=require('react');var _react2=_interopRequireDefault(_react);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj};}function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}function _possibleConstructorReturn(self,call){if(!self){throw new ReferenceError("this hasn't been initialised - super() hasn't been called");}return call&&(typeof call==="object"||typeof call==="function")?call:self;}function _inherits(subClass,superClass){if(typeof superClass!=="function"&&superClass!==null){throw new TypeError("Super expression must either be null or a function, not "+typeof superClass);}subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,enumerable:false,writable:true,configurable:true}});if(superClass)Object.setPrototypeOf?Object.setPrototypeOf(subClass,superClass):subClass.__proto__=superClass;}/**
* Base class representing an item on the dashboard. Extends it for your own item type.
*
*
* ## Declaring a new Item type
*
* To declare an Item in a plugin, you must use an ItemFactory and declare it into your plugin manifest
* { browser: { itemFactory: '...path to your factory class...' } }.
*
* See [ItemFactoryBuilder]{@link ItemFactoryBuilder} for more information.
*
*
* ## Dependencies injection
*
* Since the component will be instantiated by asterism itself, you cannot inject your own properties.
* If you need to call your own services or sockets for example, declare them properly into the manifest of your plugin,
* through { browser: { services: (context) => [my-services], publicSockets: [my-public-sockets] } }
* then your dependencies will be available in the context property. See below example.
*
*
* ## State content
*
* The component state is initialized with a params object containing item parameters (a deep copy of this.props.initialParameters):
*
* ```
* {
*     params: { ... }
* }
* ```
*
* This params state is updated by asterism through this.receiveNewParams().
* In your constructor, do never replace this.state, but use this.setState({ ...partial state... }) instead.
*
*
* ## Context content
*
* The context from props will serve a lot of usefull elements:
*
* ```
* {
*     services: array of services (e.g: const scenariiService = context.services['asterism-scenarii']. See {@tutorial services},
*     localStorage: LocalStorage (an engine to get/set values, stored on the browser side only, for this user only. See {@tutorial local-storage},
*     serverStorage: ServerStorage (an engine to get/set value, stored on the server side, shared with all users. See {@tutorial server-storage}),
*     theme: Theme (The material theme parameters. See {@tutorial theme}),
*     privateSocket: Socket (a Socket.io socket instance, private: for your plugin only),
*     publicSockets: object (with public/shared Socket.io sockets, indexed by their path identifier. You must know their use to call them. See {@tutorial socket})
*     mainState: function (e.g: to get the main state, do a context.mainState() ; to make a set, do a context.mainState.set(...))
* }
* ```
*
*
* @example <caption>Example of a constructor that links context objects (services, sockets, ...)</caption>
* class MyItem extends Item {
*     constructor (props) {
*         super(props)
*         const myService = props.context.services["my-service-id"];
*         const scenariiService = props.context.services["asterism-scenarii"];
*         const publicSocket = props.context.publicSockets["asterism/developer-tools/log"];
*         const privateSocket = props.context.privateSocket;
*     }
* }
*
* @hideconstructor
* @memberof module:Asterism
* @public
* @abstract
*/var Item=function(_React$Component){_inherits(Item,_React$Component);/**
   * React properties to use on this component.
   * You should not override these properties since you have no control on component instantiation (and then props injection).
   *
   * @property {string} id - The unique ID of the instance.
   * @property {object} initialParams - The parameters set into the component state a construction ('params' attribute). These params are updated from asterism through receiveNewParams(params).
   * @property {object} context - A context object containing useful services an other global properties. See the above details.
   * @property {array} acceptedDimensions - The dimensions (x/y) this item can take, injected through your ItemFactory instance.
   * @public
   */function Item(props){_classCallCheck(this,Item);var _this=_possibleConstructorReturn(this,(Item.__proto__||Object.getPrototypeOf(Item)).call(this,props));props.context.refresh=_this.refresh.bind(_this);props.context.freeze=_this.freeze.bind(_this);_this.state={params:_extends({},props.initialParams)// clone it, props are immutable unlike state
};return _this;}/**
   * Called by asterism when the item may receive new params (from an ItemSettingPanel for example).
   * If you need to override this, please ensure you call super.receiveNewParams() or at least do the same thing.
   *//**
   * Default properties values.
   * @property {object} initialParams - {}
   * @public
   */_createClass(Item,[{key:'receiveNewParams',value:function receiveNewParams(params){this.setState({params:params});this.params=params;console.log('New params received for item #'+this.props.id+'.');}/**
   * This refresh is called by asterism when the whole dashboard should be refreshed.
   * Override this when you should fetch data server side before to re-render the component.
   *
   * @param event {object} The event that triggered the refresh
   * @returns {Promise<void>}
   */},{key:'refresh',value:function refresh(event){var _this2=this;return new Promise(function(resolve){_this2.forceUpdate(resolve);});}/**
   * This freeze is called by asterism when the dashboard items can pause their rendering.
   * Override this when you can suspend some work when dashboard is not visible.
   * Do nothing by default. Unfreeze is achieved calling refresh method.
   *
   * @param event {object} The event that triggered the refresh
   * @returns {Promise<void>}
   */},{key:'freeze',value:function freeze(event){return Promise.resolve();}}]);return Item;}(_react2.default.Component);Item.propTypes={id:_propTypes2.default.string.isRequired,initialParams:_propTypes2.default.object,context:_propTypes2.default.object.isRequired,acceptedDimensions:_propTypes2.default.array.isRequired};Item.defaultProps={initialParams:{}};exports.default=Item;