'use strict';/**
 * The BrowserState is the class you need to override to describe the behavior of you state element (type state)
 * on the browser side. A scenarii state element will be instantiated through this extending class on the browser side.
 *
 * In your extending class, you MUST override these attributes:
 * - <YourClass>.type = { name: 'MyOwnStateType', shortLabel: 'My state', fullLabel: 'My state that represents something' }
 * - <YourClass>.get name()
 * - <YourClass>.get shortLabel()
 * - <YourClass>.get fullLabel()
 *
 * You can also override these attributes (optional):
 * - <YourClass>.constructor()
 * - <YourClass>.get EditForm()
 *
 * You need also to override ServerState in another class to describe the server side behavior of your state.
 *
 * Implementation example: see below.
 * @see https://github.com/gxapplications/asterism/blob/master/lib/plugins/scenarii/base-elements/level-state/browser.js
 * @memberof module:Scenarii
 * @public
 * @abstract
 */Object.defineProperty(exports,"__esModule",{value:true});var _createClass=function(){function defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}return function(Constructor,protoProps,staticProps){if(protoProps)defineProperties(Constructor.prototype,protoProps);if(staticProps)defineProperties(Constructor,staticProps);return Constructor;};}();function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}var BrowserState=function(){/**
   * You can override the constructor.
   * Don't forget to pass data parameter to the super() constructor.
   *
   * @public
   */function BrowserState(data){_classCallCheck(this,BrowserState);this.data=data;}/**
   * Returns the name of the state instance (not the state type).
   * The name must be very short (limit to ~25 chars approximately).
   * It is often the name of the element that is represented through the state.
   *
   * eg.: "Home alarm"
   *
   * @returns {string}
   * @public
   *//**
   * Properties to override in each extending class.
   * Type properties are supposed to describe the state type itself (not the instances of that state type).
   *
   * @property {string} name - A unique identifier for your class. Often the class name. Used in logs and for technical reasons.
   * @property {string} shortLabel - A SHORT description of your state type. Try to limit to ~25 chars approximately.
   * @property {string} fullLabel - A full description of your state type. Will complete the short label, so don't need to repeat the shortLabel inside the fullLabel, just complete. Limit to 2 lines of description.
   * @public
   */_createClass(BrowserState,[{key:'name',get:function get(){return'BrowserStateInstance';}/**
   * Returns the short label of the state instance (not the state type).
   * The short label must be quite short (limit to ~40 chars approximately).
   * It is often the short summary of the state.
   *
   * eg.: "Home alarm level"
   *
   * @returns {string}
   * @public
   */},{key:'shortLabel',get:function get(){return'Basic state instance';}/**
   * Returns the long label of the state instance (not the state type).
   * The full label must be concise but fully qualified (limit to a line of description).
   *
   * eg.: "Home alarm activation level (from 1 to 5)"
   *
   * @returns {string}
   * @public
   */},{key:'fullLabel',get:function get(){return'My basic state instance';}/**
   * Must return the component to use as Setting paneml to set/update the state instance.
   * If null, there is no setting panel, the state instance is created directly.
   *
   * @returns {React.Component}
   * @public
   */},{key:'EditForm',get:function get(){return null;}/**
   * Must return the current value of the state instance.
   * If you need to override this, use this.data.state as basement, add your business value, and return it.
   *
   * @returns {*}
   * @public
   */},{key:'state',get:function get(){return this.data.state;}}]);return BrowserState;}();BrowserState.type={name:'BrowserState',shortLabel:'Basic state',fullLabel:'My basic state',icon:'monetization_on'};exports.default=BrowserState;