'use strict';/**
 * The ServerAction is the class you need to override to describe the behavior of you scenarii element (type action)
 * on the server side. A scenarii action element will be instantiated through this extending class on the server side.
 *
 * In your extending class, you MUST override these attributes:
 * - <YourClass>.get name()
 * - <YourClass>.execute()
 *
 * You can also override these attributes (optional):
 * - <YourClass>.constructor()
 * - <YourClass>.abort()
 *
 * You need also to override BrowserAction in another class to describe the browser side behavior of your action.
 *
 * Implementation example: see below.
 * @see https://github.com/gxapplications/asterism/blob/master/lib/plugins/scenarii/base-elements/wait/server.js
 * @memberof module:Scenarii
 * @public
 * @abstract
 */Object.defineProperty(exports,"__esModule",{value:true});var _slicedToArray=function(){function sliceIterator(arr,i){var _arr=[];var _n=true;var _d=false;var _e=undefined;try{for(var _i=arr[Symbol.iterator](),_s;!(_n=(_s=_i.next()).done);_n=true){_arr.push(_s.value);if(i&&_arr.length===i)break;}}catch(err){_d=true;_e=err;}finally{try{if(!_n&&_i["return"])_i["return"]();}finally{if(_d)throw _e;}}return _arr;}return function(arr,i){if(Array.isArray(arr)){return arr;}else if(Symbol.iterator in Object(arr)){return sliceIterator(arr,i);}else{throw new TypeError("Invalid attempt to destructure non-iterable instance");}};}();var _createClass=function(){function defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}return function(Constructor,protoProps,staticProps){if(protoProps)defineProperties(Constructor.prototype,protoProps);if(staticProps)defineProperties(Constructor,staticProps);return Constructor;};}();function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}var ServerAction=function(){/**
   * You can override the constructor.
   * Don't forget to pass data parameter to the super() constructor.
   *
   * @public
   */function ServerAction(data){_classCallCheck(this,ServerAction);this.data=data;this.executionIds={};}/**
   * Returns the name of the action instance (not the action type).
   * The name must be very short (limit to ~25 chars approximately).
   * It is often the name of the element that is manipulated through the action.
   *
   * eg.: "Room light #2"
   *
   * @returns {string}
   * @public
   */_createClass(ServerAction,[{key:'execute',/**
   * This method will execute the current action instance process. It returns a Promise that will resolve after the execution.
   * This could take a while.
   *
   * @param {string} executionId - A unique execution ID, to keep on your side (to track its execution or to abort it if needed).
   * @returns {Promise} - A promise, resolving when action finished (successfully: resolve, faulty: reject).
   * @public
   */value:function execute(executionId){var _this=this;var action=Promise.resolve(true);this.executionIds[executionId]=action;return action.then(function(){delete _this.executionIds[executionId];}).catch(function(){delete _this.executionIds[executionId];});}/**
   * This method will abort the current action instance execution. It returns a Promise that will resolve after abort.
   * Abort support is optional, most of the time not supported, especially for actions with quick executions.
   * For example a "wait and do something" action should support abort, while a log action is not long enough to be abortable...
   *
   * @param executionId - A unique execution ID, used with this.execute() to abort.
   * @returns {Promise} - A promise resolving when abort is done. If the action type is not abortable, the action will finish anyway, and the returned Promise will resolve. If the execution was already stopped (finished or already aborted), the returned promise will reject.
   * @public
   */},{key:'abort',value:function abort(executionId){// See comments in devtools log action for example of an abortable action
return Promise.resolve(true);}/**
   * This method will try to abort each action instance execution in progress, of the current specific action type.
   *
   * @returns {Promise} - A promise resolving when all abort are done.
   * @public
   */},{key:'abortAll',value:function abortAll(){var _this2=this;var ids=Object.entries(this.executionIds).map(function(_ref){var _ref2=_slicedToArray(_ref,2),executionId=_ref2[0],v=_ref2[1];return executionId;});return Promise.all(ids.map(function(executionId){return{executionId:executionId,promise:_this2.abort(executionId)};})).then(function(results){return{executionIds:results.map(function(r){return r.executionId;}),result:results.reduce(function(acc,res){return acc&res;},true)};});// at least one false must give false
}},{key:'name',get:function get(){return'ServerAction';}}]);return ServerAction;}();exports.default=ServerAction;