'use strict';/**
 * The ServerCondition is the class you need to override to describe the behavior of you scenarii element (type condition)
 * on the server side. A scenarii condition element will be instantiated through this extending class on the server side.
 *
 * In your extending class, you MUST override these attributes:
 * - <YourClass>.get name()
 * - <YourClass>.test()
 *
 * You can also override these attributes (optional):
 * - <YourClass>.constructor()
 *
 * You need also to override BrowserCondition in another class to describe the browser side behavior of your condition.
 *
 * Implementation example: see below.
 * @see https://github.com/gxapplications/asterism/blob/master/lib/plugins/scenarii/base-elements/astral-time-condition/server.js
 * @memberof module:Scenarii
 * @public
 * @abstract
 */Object.defineProperty(exports,"__esModule",{value:true});var _createClass=function(){function defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}return function(Constructor,protoProps,staticProps){if(protoProps)defineProperties(Constructor.prototype,protoProps);if(staticProps)defineProperties(Constructor,staticProps);return Constructor;};}();function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}var ServerCondition=function(){/**
   * You can override the constructor.
   * Don't forget to pass data parameter to the super() constructor.
   *
   * @public
   */function ServerCondition(data){_classCallCheck(this,ServerCondition);this.data=data;}/**
   * Returns the name of the condition instance (not the condition type).
   * The name must be very short (limit to ~25 chars approximately).
   * It is often the name of the element that is manipulated through the condition.
   *
   * eg.: "Room light #2"
   *
   * @public
   */_createClass(ServerCondition,[{key:'test',/**
   * This method is overriden to make the conditional test.
   *
   * For example, a condition that test if current time is AM and not PM, it should return true if test() is called at AM time.
   * The method always returns a promise: some test could take time (but not too much: there is a short timeout of 9 seconds.
   * If the condition takes more thant 9 seconds to execute, then the behavior depends on the process that uses the condition,
   * BUT the interface will consider test as failed.
   *
   * @returns {Promise} - Resolves with true if the condition passes, with false if the condition blocks. Reject if an error occurred.
   */value:function test(){return Promise.resolve(true);}},{key:'name',get:function get(){return'ServerCondition';}}]);return ServerCondition;}();exports.default=ServerCondition;