'use strict';Object.defineProperty(exports,"__esModule",{value:true});var _createClass=function(){function defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}return function(Constructor,protoProps,staticProps){if(protoProps)defineProperties(Constructor.prototype,protoProps);if(staticProps)defineProperties(Constructor,staticProps);return Constructor;};}();var _uuid=require('uuid');var _uuid2=_interopRequireDefault(_uuid);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj};}function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}/**
 * The ServerScenario is the class you need to override to describe the behavior of you scenarii element (type scenario)
 * on the server side. A scenarii scenario element will be instantiated through this extending class on the server side.
 *
 * In your extending class, you MUST override these attributes:
 * - <YourClass>.get name()
 *
 * You can also override these attributes (optional):
 * - <YourClass>.constructor()
 * - <YourClass>.get activated()
 * - <YourClass>.set activated()
 * - <YourClass>.trigger()
 * - <YourClass>.abort()
 * - <YourClass>.afterUpdate()
 *
 * You need also to override BrowserScenario in another class to describe the browser side behavior of your scenario.
 *
 * Implementation example: see below.
 * @see https://github.com/gxapplications/asterism/blob/master/lib/plugins/scenarii/base-elements/actionable-scenario/server.js
 * @memberof module:Scenarii
 * @public
 * @abstract
 */var ServerScenario=function(){/**
   * You can override the constructor.
   * Don't forget to pass data parameter to the super() constructor.
   *
   * @public
   */function ServerScenario(data){_classCallCheck(this,ServerScenario);this.data=data;this.listeners=[];}/**
   * Returns the name of the scenario instance (not the scenario type).
   * The name must be very short (limit to ~25 chars approximately).
   * It is often the name of the element that is manipulated through the scenario.
   *
   * eg.: "Room light #2"
   *
   * @returns {string}
   * @public
   */_createClass(ServerScenario,[{key:'trigger',/**
   * This method is used to force a scenario instance to run now.
   * In most of the cases, this method should be kept as is.
   *
   * @returns {Promise} - A promise resolving when the whole process behind the scenario has finished. This can resolve before that, in an asynchronous situation.
   * @public
   */value:function trigger(executionId){var _this=this;var nextStep=arguments.length>1&&arguments[1]!==undefined?arguments[1]:function(result){return result;};var triggerChain=Promise.resolve(true).then(nextStep);triggerChain.executionId=executionId;this.listeners.forEach(function(listener){try{listener('triggered',triggerChain,_this);}catch(error){console.error(error);}});return triggerChain;}/**
   * This method is used to force a scenario instance to stop now, if possible.
   * In most of the cases, this method should be kept as is.
   *
   * @returns {Promise} - A promise resolving when abort has finished.
   * @public
   */},{key:'abort',value:function abort(executionId){var _this2=this;var nextStep=arguments.length>1&&arguments[1]!==undefined?arguments[1]:function(result){return result;};// See comments in actionable scenario for example of an abortable scenario
var triggerChain=Promise.resolve(true).then(nextStep);triggerChain.executionId=executionId;this.listeners.forEach(function(listener){try{listener('aborted',triggerChain,_this2);}catch(error){console.error(error);}});return triggerChain;}},{key:'addListener',value:function addListener(listener){listener.scenarioListenerId=_uuid2.default.v4();this.listeners.push(listener);return listener.scenarioListenerId;}},{key:'removeListener',value:function removeListener(listenerId){this.listeners=this.listeners.filter(function(listener){return listener.scenarioListenerId!==listenerId;});}/**
   * Called when scenario instance has been updated: parameters has changed, so process should be updated server side.
   *
   * @returns {Promise} - A promise resolving when update has finished.
   * @public
   */},{key:'afterUpdate',value:function afterUpdate(){// See example of asterism/plugins/scenarii/base-elements/actionable-scenario
return Promise.resolve(true);}},{key:'name',get:function get(){return'ServerScenario';}/**
   * Is this scenario instance activated?
   * If not, then the .trigger() method should do nothing...
   *
   * @returns {boolean}
   * @public
   */},{key:'activated',get:function get(){return this.data.activated;}/**
   * Changes activation state for this scenario instance.
   *
   * @param {boolean} value - To activate the scenario, should be true.
   * @public
   */,set:function set(value){var _this3=this;this.data.activated=!!value;this.listeners.forEach(function(listener){try{listener('activationChanged',value,_this3);}catch(error){console.error(error);}});}}]);return ServerScenario;}();exports.default=ServerScenario;