'use strict';Object.defineProperty(exports,"__esModule",{value:true});var _createClass=function(){function defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}return function(Constructor,protoProps,staticProps){if(protoProps)defineProperties(Constructor.prototype,protoProps);if(staticProps)defineProperties(Constructor,staticProps);return Constructor;};}();var _uuid=require('uuid');var _uuid2=_interopRequireDefault(_uuid);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj};}function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}/**
 * The ServerState is the class you need to override to describe the behavior of you scenarii element (type state)
 * on the server side. A scenarii state element will be instantiated through this extending class on the server side.
 *
 * In your extending class, you MUST override these attributes:
 * - <YourClass>.get name()
 *
 * You can also override these attributes (optional):
 * - <YourClass>.constructor()
 * - <YourClass>.get state()
 * - <YourClass>.set state()
 * - <YourClass>.preValidate()
 *
 * You need also to override BrowserAction in another class to describe the browser side behavior of your action.
 *
 * Implementation example: see below.
 * @see https://github.com/gxapplications/asterism/blob/master/lib/plugins/scenarii/base-elements/level-state/server.js
 * @memberof module:Scenarii
 * @public
 * @abstract
 */var ServerState=function(){/**
   * You can override the constructor.
   * Don't forget to pass data parameter to the super() constructor.
   *
   * @public
   */function ServerState(data){_classCallCheck(this,ServerState);this.data=data;this.listeners=[];}/**
   * Returns the name of the state instance (not the state type).
   * The name must be very short (limit to ~25 chars approximately).
   * It is often the name of the concept that is manipulated through the state.
   *
   * eg.: "Alarm level"
   *
   * @returns {string}
   * @public
   */_createClass(ServerState,[{key:'preValidate',/**
   * Prevalidate the new state value.
   * This call will ask state listeners with the new value, to know if one of the listeners accepts the new value.
   * If one reject the new value, then the state is not updated.
   *
   * @param {*} state - The new value proposed for the state.
   * @param {*} oldState - The value before update, to let listener compare and decide.
   * @returns {boolean} - If true, listeners accept the new value. Update can be done.
   * @public
   */value:function preValidate(state,oldState){var _this=this;var validate=true;this.listeners.forEach(function(listener){try{if(listener.preValidate){validate=validate&&listener.preValidate(state,_this,oldState);}}catch(error){console.error(error);}});return validate;}/** @private */},{key:'addListener',value:function addListener(listener){listener.stateListenerId=_uuid2.default.v4();this.listeners.push(listener);return listener.stateListenerId;}/** @private */},{key:'removeListener',value:function removeListener(listenerId){this.listeners=this.listeners.filter(function(listener){return listener.stateListenerId!==listenerId;});}},{key:'name',get:function get(){return'ServerState';}/**
   * Gets actual state value.
   *
   * @returns {*} - The state value (type will vary depending on your implementation)
   * @public
   */},{key:'state',get:function get(){return this.data.state;}/**
   * Sets state value.
   * This call will trigger state listeners with the new value.
   *
   * @param {*} state - The value to set on the state.
   * @public
   */,set:function set(state){var _this2=this;// if listeners have preValidate and one of these returns false, then do not update state
if(!this.preValidate(state)){return;}this.data.state=state;this.listeners.forEach(function(listener){try{listener(state,_this2);}catch(error){console.error(error);}});}}]);return ServerState;}();exports.default=ServerState;